@@ -6,12 +6,18 @@ loaded_packages <- function() {
   ## 'base' is special, because getNamespaceInfo does not work on it.
   ## Luckily, the path for 'base' is just system.file()
 
-  spackageVersion <- function(pkg) as.character(packageVersion(pkg))
+  spackageVersion <- function(pkg) {
+    as.character(packageVersion(pkg, lib.loc = .libPaths()))
+  }
 
   packages <- setdiff(loadedNamespaces(), "base")
   loadedversion <- vapply(packages, getNamespaceVersion, "")
   ondiskversion <- vapply(packages, spackageVersion, "")
-  path <- vapply(packages, getNamespaceInfo, "", "path")
+  path <- vapply(
+    packages,
+    function(p) system.file(package = p, lib.loc = .libPaths()),
+    character(1))
+  loadedpath <- vapply(packages, getNamespaceInfo, "", which = "path")
   attached <- paste0("package:", packages) %in% search()
 
   res <- data.frame(
@@ -19,6 +25,7 @@ loaded_packages <- function() {
     ondiskversion = c(ondiskversion, spackageVersion("base")),
     loadedversion = c(loadedversion, getNamespaceVersion("base")),
     path = c(path, system.file()),
+    loadedpath = c(loadedpath, NA_character_),
     attached = c(attached, TRUE),
     stringsAsFactors = FALSE,
     row.names = NULL
