@@ -5,7 +5,7 @@
 #' On macOS it includes the code names, on Linux it includes the
 #' distribution names and codenames if appropriate.
 #'
-#' It uses [utils::sesssionInfo()], but simplifies its output a bit
+#' It uses [utils::sessionInfo()], but simplifies its output a bit
 #' on Windows, to make it more concise.
 #'
 #' @return A character scalar.
@@ -14,7 +14,8 @@
 
 os_name <- function() {
   x <- utils::sessionInfo()$running
-
+  if (is.null(x)) return(NA_character_)
+  
   # Regexps to clean up long windows strings generated at
   # https://github.com/wch/r-source/blob/af7f52f70101960861e5d995d3a4bec010bc89e6/src/library/utils/src/windows/util.c
 
